@@ -591,12 +591,15 @@ class DSLibrary(object):
         format, alias_options = FORMAT_ALIASES_WRITE_OPTIONS.get(format, (format, {}))
         format_options.update(alias_options)
         # detect SQL target
-        if kwargs.get("sql_table"):
+        sql_source = kwargs.get("sql_source")
+        sql_table = kwargs.get("sql_table")
+        if sql_source or sql_table:
             # write data to an SQL table
-            db_conn = self.get_sql_connection(resource_name, database=kwargs.get("database"))
+            sql_source = sql_source or resource_name
+            db_conn = self.get_sql_connection(sql_source, database=kwargs.get("database"))
             content = _coerce_to_dataframe(content)
             try:
-                table = kwargs.get("sql_table")
+                table = sql_table or resource_name
                 for sql, params in dataframe_to_sql(content, table_name=table, append=append):
                     db_conn.cursor().execute(sql, params)
             finally:
@@ -856,8 +859,10 @@ class DSLibrary(object):
             format - csv, json, etc
             format_options - these are passed to pandas.read_csv(), etc.
             filesystem - name of a filesystem
+            sql_source - named source of SQL data
             sql - SQL to execute
             sql_table - name of table to fully load
+            nosql_source - named source of NoSQL data
             nosql_collection - name of a NoSQL collection to fully load
             run_data - True to read using open_run_data()
             dask - True to load into a dask dataframe, or an integer to load into dask if file size is >= to threshold (or unknown).
@@ -898,27 +903,47 @@ class DSLibrary(object):
             uri, uri_args = uri.split("#", maxsplit=1)
             for k, v in urllib.parse.parse_qs(uri_args).items():
                 format_options[k] = v[0] if len(v) == 1 else v
+        # detect SQL
+        sql_source = open_args.pop("sql_source", None)
+        sql_table = open_args.pop("sql_table", None)
+        sql_sql = open_args.pop("sql", None)
+        if sql_source or sql_sql or sql_table:
+            if sniff_only:
+                open_args["sniff_only"] = True
+            # NOTE: 'or resource_name' is backup for sql_source, for backward compatibility (could be removed soon)
+            db_conn = self.get_sql_connection(sql_source or resource_name, **open_args)
+            # - otherwise it is used as a table name or SQL
+            if not sql_table and not sql_sql:
+                if resource_name.lower().startswith("select "):
+                    sql_sql = resource_name
+                else:
+                    sql_table = resource_name
+            if sql_table:
+                # NOTE: 'or resource_name' is backup for table name
+                flavor = db_conn_flavor(db_conn)
+                sql_sql = f"SELECT * from {sql_enquote_id(sql_table or resource_name, dotted=True, mode=flavor)}"
+            if sniff_only:
+                connect_strategy = db_conn
+                return LoadStrategy(opener=connect_strategy.opener, open_args=connect_strategy.open_args,
+                                    read_method=load_dataframe_from_sql, use_dask=use_dask, sql=sql_sql)
+            return load_dataframe_from_sql(db_conn, sql_sql, use_dask)
+        # detect NoSQL
+        nosql_source = open_args.pop("nosql_source", None)
+        nosql_collection = open_args.pop("nosql_collection", None)
+        if nosql_source or nosql_collection:
+            if sniff_only:
+                open_args["sniff_only"] = True
+            db_conn = self.get_nosql_connection(nosql_source, **open_args)
+            if sniff_only:
+                connect_strategy = db_conn
+                # TODO sniffing for nosql - not finished
+                return LoadStrategy(opener=connect_strategy.opener, open_args=connect_strategy.open_args,
+                                    read_method=load_dataframe_from_sql, use_dask=use_dask, sql=sql_sql)
+            # - 'or resource_name' is backup for 'nosql_collection'
+            rows = list(db_conn.query(nosql_collection or resource_name))
+            return pandas.DataFrame(rows)
+        # other types...
         if isinstance(resource_name, str):
-            # detect SQL
-            if open_args.get("sql") or open_args.get("sql_table"):
-                sql = open_args.pop("sql", None)
-                table = open_args.pop("sql_table", None)
-                if sniff_only:
-                    open_args["sniff_only"] = True
-                db_conn = self.get_sql_connection(resource_name, **open_args)
-                if table:
-                    flavor = db_conn_flavor(db_conn)
-                    sql = f"SELECT * from {sql_enquote_id(table, dotted=True, mode=flavor)}"
-                if sniff_only:
-                    connect_strategy = db_conn
-                    return LoadStrategy(opener=connect_strategy.opener, open_args=connect_strategy.open_args, read_method=load_dataframe_from_sql, use_dask=use_dask, sql=sql)
-                return load_dataframe_from_sql(db_conn, sql, use_dask)
-            # detect NoSQL
-            if open_args.get("nosql_collection"):
-                collection = open_args.pop("nosql_collection")
-                db_conn = self.get_nosql_connection(resource_name, **open_args)
-                rows = list(db_conn.query(collection))
-                return pandas.DataFrame(rows)
             # TODO we should offer a validation option that checks the data types against the schema
             # format can be specified, or file extension will be used
             file_extension = find_url_extension(uri)
