@@ -52,6 +52,29 @@ VALID_OPTIONS = {
     "xlsx": VALID_EXCEL_OPTIONS,
     "parquet": VALID_PARQUET_OPTIONS
 }
+VALID_DOUBLE_EXTENSIONS = (
+    ".csv.zip", "csv.gzip"
+)
+FORMAT_ALIASES_READ_OPTIONS = {
+    "csv": ("csv", {}),
+    "json": ("json", {}),
+    "yml": ("yaml", {}),
+    "pq": ("parquet", {}),
+    "h5": ("hdf", {}),
+    "csv.zip": ("csv", {"compression": "zip"}),
+    "csv.gzip": ("csv", {"compression": "gzip"}),
+    "tab": ("csv", {"delimiter": "\t"}),
+    "tsv": ("csv", {"delimiter": "\t"}),
+    "txt": ("csv", {"names": ["line"], "delimiter": "\0"})
+}
+FORMAT_ALIASES_WRITE_OPTIONS = {
+    "pq": ("parquet", {}),
+    "h5": ("hdf", {}),
+    "csv.zip": ("csv", {"compression": "zip"}),
+    "csv.gzip": ("csv", {"compression": {'method': 'gzip'}}),
+    "tab": ("csv", {"delimiter": "\t"}),
+    "tsv": ("csv", {"delimiter": "\t"})
+}
 
 
 def detect_format(
@@ -82,19 +105,9 @@ def detect_format(
         format = supplied_options["format"]
     read_args = {}
     # normalize the format and infer things
-    FORMAT_ALIASES_ETC = {
-        "csv": ("csv", {}),
-        "json": ("json", {}),
-        "yml": ("yaml", {}),
-        "pq": ("parquet", {}),
-        "h5": ("hdf", {}),
-        "tab": ("csv", {"delimiter": "\t"}),
-        "tsv": ("csv", {"delimiter": "\t"}),
-        "txt": ("csv", {"names": ["line"]})
-    }
     orig_format = (format or "").lower()
     if format:
-        format, implied_defaults = FORMAT_ALIASES_ETC.get(format.lower(), (format, {}))    # determine format based on a sample
+        format, implied_defaults = FORMAT_ALIASES_READ_OPTIONS.get(format.lower(), (format, {}))    # determine format based on a sample
         read_args.update(implied_defaults)
     size = sizer() if sizer and hasattr(sizer, "__call__") else sizer
     avg_line_size = None
@@ -152,7 +165,11 @@ def find_url_extension(url: str) -> str:
         url = url.split("#")[0]
     if "?" in url:
         url = url.split("?")[0]
-    return os.path.splitext(url)[1].lower().strip(".")
+    url_l = url.lower()
+    for dbl in VALID_DOUBLE_EXTENSIONS:
+        if url_l.endswith(dbl):
+            return dbl.strip(".")
+    return os.path.splitext(url_l)[1].strip(".")
 
 
 def average_line_size(sample):
