@@ -246,7 +246,7 @@ class TestFront(unittest.TestCase):
         self.assertEqual(log[0], 'default.csv')
         self.assertEqual(log[-1], 'override.csv')
 
-    def test_load_dataframe__from_sql(self):
+    def test_load_dataframe__from_sql_1(self):
         log = []
         class MyInst(DSLibrary):
             def get_sql_connection(self, resource_name: str, for_write: bool=False, **kwargs):
@@ -657,7 +657,7 @@ class TestFront(unittest.TestCase):
         df = MyInst().load_dataframe("x")
         self.assertEqual(list(df.columns), ["a", "b"])
         # here we force the delimited to be a linefeed and now there is only one column
-        df = MyInst().load_dataframe("x#delimiter=%0a")
+        df = MyInst().load_dataframe("x#delimiter=%00")
         self.assertEqual(list(df.columns), ["a,b"])
 
     def test_hdf(self):
@@ -714,7 +714,7 @@ class TestFront(unittest.TestCase):
                 else:
                     self.assertEqual(os.listdir(fn), ["0.part"])
                     assert len(parts) == 1
-                df = MyInst().load_dataframe(fn, dask=True, format_options={"delimiter": "\n"}).compute()
+                df = MyInst().load_dataframe(fn, dask=True, format_options={"delimiter": "\0"}).compute()
                 self.assertEqual(list(df.x), list(range(100)))
             finally:
                 shutil.rmtree(tmpdir)
@@ -769,3 +769,43 @@ class TestFront(unittest.TestCase):
                 return write_stream_with_read_on_close(mode, 'r', on_close=store)
         MyInst().write_resource('f', pandas.DataFrame({"x": [1, 2], "y": [10, 20]}), format_options={"format": "csv", "sep": ";"})
         self.assertEqual(files["f"], 'x;y\n1;10\n2;20\n')
+
+    def test_from_sql_2(self):
+        log = []
+        class MyInst(DSLibrary):
+            def get_sql_connection(self, resource_name: str, for_write: bool=False, **kwargs):
+                log.append(("connect", resource_name, for_write, kwargs))
+                class DbCursor(object):
+                    description = [("x", None)]
+                    def execute(self, sql):
+                        log.append(sql)
+                    def __iter__(self):
+                        return iter([(1,), (2,)])
+                class DbConn(object):
+                    def cursor(self):
+                        return DbCursor()
+                    def close(self):
+                        log.append("close")
+                return DbConn()
+        # resource_name is a table
+        df = MyInst().load_dataframe("table1", sql_source="sql1")
+        self.assertEqual(list(df.x), [1, 2])
+        self.assertEqual(log, [('connect', 'sql1', False, {}), 'SELECT * from table1', 'close'])
+        # resource_name is SQL
+        log.clear()
+        df = MyInst().load_dataframe("select * from table2", sql_source="sql1")
+        self.assertEqual(list(df.x), [1, 2])
+        self.assertEqual(log, [('connect', 'sql1', False, {}), 'select * from table2', 'close'])
+        # resource_name is SQL
+        log.clear()
+        df = MyInst().load_dataframe(None, sql_source="sql1", sql_table="table 3")
+        self.assertEqual(list(df.x), [1, 2])
+        self.assertEqual(log, [('connect', 'sql1', False, {}), 'SELECT * from "table 3"', 'close'])
+
+    def test_nrows(self):
+        project = tempfile.mkdtemp()
+        dsl = DSLibraryLocal(project, spec={"outputs": {METRICS_ALIAS: {"format": "csv"}}})
+        dsl.write_resource(project+"/f1.csv", pandas.DataFrame({"x": range(10)}))
+        df = dsl.load_dataframe(project+"/f1.csv", format_options={"nrows": 2})
+        shutil.rmtree(project)
+        self.assertEqual(list(df.x), [0, 1])
